﻿-- Daily Global Check
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local L = addonTable.L

local tx_list_background  = "Interface\\Stationery\\Stationery_ill1"
local tx_list_background2 = "Interface\\Stationery\\Stationery_ill2"

DailyGlobalCheck = {}
DailyGlobalCheck.CharFunctions  = {}
DailyGlobalCheck.PagesFunctions = {}
DailyGlobalCheck.OptFunctions   = {}
DailyGlobalCheck.Constructors   = {}
DailyGlobalCheck.ListFunctions  = {}
DailyGlobalCheck.MenuFunctions  = {}
DailyGlobalCheck.MapFunctions   = {}
DailyGlobalCheck.HelpFunctions   = {}

-- string colors
local colors = {
 LIGHT_RED    = "|cffFF2020",
 LIGHT_GREEN  = "|cff20FF20",
 LIGHT_BLUE   = "|cff11DDFF",
 LIGHT_YELLOW = "|cffFFFFAA",
 ZONE_BLUE    = "|cff00aacc",
 GRAY         = "|cffAAAAAA",
 NAME_COLOR   = "|cffffffcc",
 COORD_COLOR  = "|cffDDDDDD",
 GOLD         = "|cffffcc00",
 WHITE        = "|cffffffff",
 LIST_COLOR   = "|cff00DD11"
}

function addonTable.AddColor(str,color)
 local c = colors[color]
 if not str then return "|cffFF0000<Error>|r" end
 if not c then return str end
 return c..str.."|r"
end
local AddColor = addonTable.AddColor

local btnheight = 25
local pool = {}
local chars = DailyGlobalCheck.CharFunctions
local options = DailyGlobalCheck.OptFunctions
local constructors = DailyGlobalCheck.Constructors

constructors.pluginbtnsize = 25
local pluginbtnsize = constructors.pluginbtnsize

local panel_backdrop   =  { bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",  
                            edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
                            tile = true,
                            tileSize = 32,
                            edgeSize = 32,
                            insets = { left = 11, right = 12, top = 12, bottom = 11 }
                          }

local frames_backdrop  = { bgFile = "Interface\\Buttons\\GreyscaleRamp64", 
                           edgeFile = "Interface\\Buttons\\WHITE8X8", 
						   edgeSize = 1
						 }

local buttons_backdrop = {bgFile = "Interface/Tooltips/UI-Tooltip-Background", 
                         edgeFile = "Interface/Tooltips/UI-Tooltip-Border", 
                         tile = true, tileSize = 16, edgeSize = 16, 
                         insets = { left = 4, right = 4, top = 4, bottom = 4 }}

local function SetTooltip(f, l)
 f:SetScript("OnLeave", function(self)
    GameTooltip:Hide()
   end)
 f:SetScript("OnEnter", function(self)
    GameTooltip:SetOwner(f,"ANCHOR_TOP",0,5)
    GameTooltip:ClearLines()
	table.foreach(l, function(_,v)
     GameTooltip:AddLine(v)
	end)
    GameTooltip:Show()
   end)
end

local function createTexture(f, t, tvar)
 tvar = tvar or "tex"
 f[tvar] = f:CreateTexture()
 local tex = f[tvar]
 tex:SetAllPoints()
 if type(t) == "table" then
  tex:SetTexture(unpack(t))
 else
  tex:SetTexture(t)
 end
end

local function setMovable(f, clamped)
 f:EnableMouse(true)
 f:SetMovable(true)
 if clamped then f:SetClampedToScreen(true) end
 f:RegisterForDrag("LeftButton")
 f:SetScript("OnDragStart", function(self) f:StartMoving() end)
 f:SetScript("OnDragStop",  function(self) f:StopMovingOrSizing() end)
end

-------- Frames --------
function constructors:Panel(p, name, w, h, backdrop)
 local f = CreateFrame("Frame", name, p)
 if backdrop then
  f:SetBackdrop(frames_backdrop)
  f:SetBackdropColor(0, 0.02, 0.05, 0.9)
  f:SetBackdropBorderColor(0, 0.05, 0.15, 0.9)
 else
  createTexture(f, {0, 0, 0, 0.9})
 end
 setMovable(f, false)
 f:SetSize(w, h)
 f:Hide()
 return f
end

function constructors:DGCFrame(p, name, w, h)
 local f = CreateFrame("Frame", name, p)
 f:SetSize(w,h)
 f:SetBackdrop(frames_backdrop)
 f:SetBackdropColor(0.07,0.07,0.07,0.9)
 f:SetBackdropBorderColor(0.1,0.1,0.1,0.9)
 f:Hide()
 return f
end
-----------------------------

--------- ListBox ---------
function constructors:ListBox(p, name, w, h, buttontype, updatefunc, btnclickfunc, onbtnselected)
 local scrollframe = CreateFrame("ScrollFrame", name, p, "HybridScrollFrameTemplate") 
 scrollframe.tex = scrollframe:CreateTexture()
 scrollframe.tex:SetPoint("TOPLEFT")
 scrollframe.tex:SetPoint("BOTTOMRIGHT", scrollframe, "BOTTOMRIGHT", -50, 0)
 scrollframe.tex:SetTexture(tx_list_background)
 scrollframe.tex:SetVertexColor(0.5,0.5,0.5,1)
 scrollframe.tex2 = scrollframe:CreateTexture()
 scrollframe.tex2:SetPoint("TOPLEFT", scrollframe, "TOPRIGHT", -50, 0) 
 scrollframe.tex2:SetPoint("BOTTOMRIGHT")
 scrollframe.tex2:SetTexture(tx_list_background2)
 scrollframe.tex2:SetVertexColor(0.5,0.5,0.5,1)
 scrollframe:SetFrameLevel(p:GetFrameLevel() + 1)
 scrollframe:EnableMouse(true)
 scrollframe:SetSize(w, h)

 local scrollbar = CreateFrame("Slider", name.."ScrollBar", scrollframe, "HybridScrollBarTemplate")
 scrollbar:SetPoint("TOPLEFT", scrollframe, "TOPRIGHT", 4, -13)
 scrollbar:SetPoint("BOTTOMLEFT", scrollframe, "BOTTOMRIGHT", 4, 13)
 --scrollbar.doNotHide = true
 scrollframe.scrollBar = scrollbar

 HybridScrollFrame_CreateButtons(scrollframe, buttontype, 0, 0, "TOPLEFT", "TOPLEFT", 0, 0, "TOP", "BOTTOM")

 for i = 1, #(scrollframe.buttons) do
  scrollframe.buttons[i]:SetWidth(scrollframe:GetWidth())
  scrollframe.buttons[i].func = btnclickfunc
  scrollframe.buttons[i].index = i
 end

 scrollframe.buttons.Select = function(self, button)
  local offset = HybridScrollFrame_GetOffset(self)
  self.selected = button.index + offset
  for i = 1, #self.buttons do
   self.buttons[i]:UnlockHighlight()
  end
  button:LockHighlight()
 end
 
 scrollframe.OnButtonSelected = onbtnselected
 
 scrollframe.SetView = function(self, st)
  for i = 1, #(self.buttons) do
   if st == "Lists" then
	self.buttons[i].icon:Show()
    self.buttons[i].icon2:Show()
    self.buttons[i].name:Show()
	self.buttons[i].name:SetPoint("LEFT", self.buttons[i], "LEFT", 16, 0)
	self.buttons[i].zone:Hide()
	self.buttons[i].questID:Hide()
   elseif st == "Quests" then
    self.buttons[i].icon:SetTexture("Interface\\Minimap\\ObjectIcons")
	self.buttons[i].icon:SetPoint("LEFT", self.buttons[i], "LEFT", 30, 0)
    self.buttons[i].icon:Show()
	self.buttons[i].icon2:SetSize(16,16)
	self.buttons[i].icon2:ClearAllPoints()
	self.buttons[i].icon2:SetPoint("LEFT")
    self.buttons[i].icon2:Hide()
	self.buttons[i].questID:SetPoint("LEFT", self.buttons[i], "LEFT", 5 + self.columns[1]:GetWidth() + self.columns[2]:GetWidth(), 0)
	self.buttons[i].questID:SetWidth(self.columns[3]:GetWidth())
	self.buttons[i].questID:Show()
	self.buttons[i].zone:SetPoint("LEFT", self.buttons[i].questID, "LEFT", 5 + self.columns[3]:GetWidth(), 0)
	self.buttons[i].zone:SetWidth(self.columns[4]:GetWidth())
	self.buttons[i].zone:Show()
	self.buttons[i].name:SetPoint("LEFT", self.buttons[i].zone, "LEFT", 5 + self.columns[4]:GetWidth(), 0)
	self.buttons[i].name:SetWidth(self.columns[5]:GetWidth())
    self.buttons[i].name:Show()
   end
  end
 end
 
 scrollframe.update = updatefunc
 
 scrollframe:SetScript("OnShow", function(self) self:update() end)

 return scrollframe
end
--------------------

local edt_counter = 1
function constructors:EditBox(p, title, func)
 local edt = CreateFrame("EditBox", "DGC_OptEditBox"..edt_counter, p)
 if title then
  edt.lbl = edt:CreateFontString()
  edt.lbl:SetFont("Fonts\\ARIALN.ttf", 14, "")
  edt.lbl:SetText(title)
  edt.lbl:SetPoint("BOTTOMLEFT", edt, "TOPLEFT", 0, 0) 
 end
 edt:SetFontObject("GameFontHighlight")
 edt:SetWidth(60)
 edt:SetHeight(25)
 edt:SetBackdrop(GameTooltip:GetBackdrop())
 edt:SetBackdropColor(0, 0, 0, 0.8)
 edt:SetBackdropBorderColor(0.6, 0.6, 0.6, 1)
 edt:SetTextInsets(10, 0, 0, 0)
 edt:SetAutoFocus(false)
 local f = function(self) self:ClearFocus() if func then func(self) end end
 edt:SetScript("OnEnterPressed", f)
 edt:SetScript("OnEscapePressed", f)
 edt:ClearFocus()
 edt_counter = edt_counter + 1
 return edt
end

-- da rivedere
function constructors:DGCButton(p, name, text)
 local f = CreateFrame("Button", name, p, "UIPanelButtonTemplate")
 f:SetText(text or "")
 return f
end

function constructors:CreateListButton(p, name)
 local f = CreateFrame("Frame",name,p)
 f:SetHeight(btnheight)

 f.btn = CreateFrame("Button",nil,f)
 f.btn:SetPoint("TOPLEFT", f, "TOPLEFT", 1, -1)
 f.btn:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", -1, 1)
 f.btn.text = f.btn:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 f.btn.text:SetPoint("CENTER")

 f.btn.tex = f.btn:CreateTexture(nil)
 f.btn.tex:SetAllPoints()
 f.btn.tex:SetTexture(0.2,0.2,0.2,0.5)
 
 f.SetIcon = function(self,s)
              f.btn.tex:SetTexture(s)
             end
 f.SetText = function(self,s)
              f.btn.text:SetText(s)
             end
 f.Select =  function(self)
			  self.btn.tex:SetVertexColor(0, 0.7, 0)
             end
 f.Deselect = function(self)
			   self.btn.tex:SetVertexColor(1, 1, 1)
              end
 f.btn:SetPoint("CENTER", f, "CENTER")
 f.btn:SetSize(13,btnheight-2)
  f.btn:SetScript("OnClick", function()
    if f.clickfunc then f:clickfunc() end
 end)
 f.btn:SetScript("OnEnter", function()
   if f.tooltiplines then
	GameTooltip:SetOwner(f, "ANCHOR_NONE")
	GameTooltip:SetPoint("BOTTOM", f, "TOP", 0, 5)
    GameTooltip:ClearLines()
	GameTooltip:AddLine("")
    table.foreach(f.tooltiplines, function(k,v)
	 GameTooltip:AddLine(v)
	end)
	GameTooltip:Show()
   end
  end)
 f.btn:SetScript("OnLeave", function()
    GameTooltip:Hide()
 end)

 f.btn:SetHighlightTexture("Interface\\buttons\\UI-Listbox-Highlight2", "ADD")
 table.insert(pool, f)
 return f
end

-- a simple textured frame
function constructors:CreateStaticBtn(parent, tex, pos, tooltiptext)
 local f = CreateFrame("Frame", nil, parent)
 f:SetSize(25,25)
 f:SetPoint(unpack(pos))
 f.tex = f:CreateTexture()
 f.tex:SetAllPoints()
 f.tex:SetTexture(tex)
 SetTooltip(f, tooltiptext)
 return f
end

-- a static button which can be used to show a panel
function constructors:CreatePanelBtn(parent, tex, panel, pos, tooltiptext)
 local f = constructors:CreateStaticBtn(parent, tex, pos, tooltiptext)
 f.tex:SetVertexColor(1,1,1,1)
 f.open = false

 f.func = function(self)
  self.open = not self.open
  if self.open then
   self.tex:SetVertexColor(0,1,0,1)
   panel:Show()
  else
   self.tex:SetVertexColor(1,1,1,1)
   panel:Hide()
  end
 end
 
 f:SetScript("OnMouseUp", f.func)
 
 return f
end

local function CreateListItem(p)
-- background frame
 local f
 local j
 for _,j in pairs(pool) do
  if not j.used then
   f = j
   break
  end
 end
 if not f then f = CreateSingleButton(p) end
 f.used = true
 return f
end

function constructors:largebuttontemplate(p, text, tooltiptext)
  result = CreateFrame("FRAME", nil, p)
  result:SetWidth(60)
  result:SetHeight(25)
  result.text = result:CreateFontString(nil, "OVERLAY")
  result.text:SetAllPoints()
  result.text:SetFont("Fonts\\FRIZQT__.TTF", 12)
  result.text:SetText(text)
  result:SetBackdrop(buttons_backdrop)
  SetTooltip(result, {tooltiptext})
  return result
end

local chkcounter = 0
function constructors:checkboxtemplate(p, width, text)
 local f = CreateFrame("CheckButton", "DGC_OptCheckbox"..chkcounter, p, "OptionsCheckButtonTemplate")
 local txt = _G[f:GetName().."Text"]
 txt:SetWidth(width)
 txt:SetWordWrap(true)
 txt:SetText(text)
 f.title = txt
 chkcounter = chkcounter + 1
 return f
end

function constructors:SetupFrame(f, backdrop_only)
 f:SetBackdrop(frames_backdrop)
 f:SetBackdropColor(0.07,0.07,0.07,0.9)
 f:SetBackdropBorderColor(0.1,0.1,0.1,0.9)
 
 if backdrop_only then return end
 
 f:SetFrameStrata("HIGH")
 f.leftfont = f:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 f.rightfont = f:CreateFontString(nil, "OVERLAY", "GameTooltipText")
 f.rightfont:SetJustifyH("RIGHT")
 f.leftfont:SetPoint("TOPLEFT",5,-5)
 f.rightfont:SetPoint("TOPRIGHT",-5,-5)
end